<?php

use EventPortal\Domain\Admin\Handlers\AssignRole;
use EventPortal\Domain\Admin\Handlers\CreateAdmin;
use EventPortal\Domain\Admin\Handlers\UpdateAdmin;
use EventPortal\Domain\Admin\Handlers\UpdateAssignedRole;
use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\User\Handlers\CreateUser;
use EventPortal\Domain\User\Handlers\UpdateUser;
use EventPortal\Enums\InertiaMethod;

Form::make('admin.create')
    ->addSaveHandler(new CreateUser)
    ->addSaveHandler(new CreateAdmin)
    ->addSaveHandler(new AssignRole)
    ->addFields(function () {
        return [
            Section::make('Contact details')->fields([
                Text::make('First name')->rules(['required']),
                Text::make('Last name')->rules(['required']),
            ]),
            Section::make('Contact details')->fields([
                Text::make('Email')->rules(['required', 'email', 'unique:users,email']),
            ]),
            Section::make('User role')->fields([
                Select::make('Role')
                    ->name('role_id')
                    ->options(Role::allAsOptions())
                    ->placeholder('Please select a role')
                    ->rules(['required']),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.user.index'),
            Button::make('Create User')
                ->method(InertiaMethod::POST())
                ->route('admin.user.store'),
        ];
    });

Form::make('admin.edit')
    ->addSaveHandler(new UpdateAssignedRole)
    ->addSaveHandler(new UpdateAdmin)
    ->addSaveHandler(new UpdateUser)
    ->addFields(function (Admin $admin) {
        return [
            Section::make('Contact details')->fields([
                Text::make('First name')->rules(['required'])->scopeTo('user'),
                Text::make('Last name')->rules(['required'])->scopeTo('user'),
            ]),
            Section::make('Contact details')->fields([
                Text::make('Email')->rules(['required', 'email'])->scopeTo('user'),
            ]),
            Section::make('User role')->fields([
                Select::make('Role')
                    ->name('role_id')
                    ->options(Role::allAsOptions())
                    ->value($admin->roleAsOption())
                    ->placeholder('Please select a role')
                    ->rules(['required']),
            ]),
        ];
    })
    ->addActions(function (Admin $admin) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.user.index'),
            Button::make('Update user')
                ->method(InertiaMethod::POST())
                ->route('admin.user.update', ['admin' => $admin->id]),
        ];
    });

Form::make('admin.show')
    ->addFields(function () {
        return [
            Section::make('')->fields([
                Display::make('First name')->scopeTo('user'),
                Display::make('Last name')->scopeTo('user'),
                Display::make('Username'),
            ]),
            Section::make('')->fields([
                Display::make('Email')->scopeTo('user'),
                Display::make('Phone'),
            ]),
            Section::make('')->fields([
                Display::make('Department'),
                Display::make('Job title'),
                Display::make('Team'),
            ]),
            Section::make('')->fields([
                Display::make('Role'),
            ]),
        ];
    })
    ->addActions(function (Admin $admin) {
        return [
            Button::make('Delete')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.user.index'),
            Button::make('Edit')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.user.edit', ['admin' => $admin->id]),
        ];
    });
