<?php

namespace EventPortal\Seeds;

use EventPortal\Domain\Permission\Models\Group;
use EventPortal\Domain\Permission\Models\Permission;
use Illuminate\Database\Seeder;
use Illuminate\Support\Str;

class PermissionSeeder extends Seeder
{
    public function run(): void
    {
        $permissions = collect([
            'Event Management' => [
                'event.manage',
                'event.show',
                'event.store',
                'event.update',
                'event.destroy',
            ],
            'Team Management' => [
                'team.manage',
                'team.show',
                'team.store',
                'team.update',
                'team.destroy',
            ],
            'User Management' => [
                'user.manage',
                'user.show',
                'user.store',
                'user.update',
                'user.destroy',
            ],
        ]);

        $permissions->each(static function (array $permission, string $group): void {
            $group = Group::firstOrCreate([
                'name' => Str::slug($group),
                'label' => Str::ucfirst($group),
            ]);

            collect($permission)->each(static function (string $permission) use ($group): void {
                $model = Str::plural(Str::title(Str::before($permission, '.'))); // event -> Events
                $method = Str::title(Str::after($permission, '.')); // manage -> Manage

                Permission::updateOrCreate([
                    'name' => $permission,
                    'label' => "{$method} {$model}",
                    'guard_name' => 'web',
                    'group_id' => $group->id,
                ]);
            });
        });
    }
}
